<?php
/**
 * Custom functions
 *
 * @package Yudlee Themes
 * @subpackage Whitish Lite
 * @since Whitish Lite 1.0
 */

/********************* Whitish Lite RESPONSIVE AND CUSTOM CSS OPTIONS ***********************************/
if (! function_exists('whitish_lite_resp_and_custom_css')) {
	function whitish_lite_resp_and_custom_css() {
		$whitish_lite_settings = whitish_lite_get_theme_options(); ?>
		<?php
		if (!empty($whitish_lite_settings['whitish_lite_custom_css'] ) ){
				$whitish_lite_internal_css = $whitish_lite_settings['whitish_lite_custom_css'];
		}

		wp_add_inline_style( 'whitish-lite-style', $custom_css );
	}
}

/******************************** EXCERPT LENGTH *********************************/
if (! function_exists('whitish_lite_excerpt_length')) {
	function whitish_lite_excerpt_length($length) {
		$whitish_lite_settings = whitish_lite_get_theme_options();
		$whitish_lite_excerpt_length = $whitish_lite_settings['whitish_lite_excerpt_length'];
		return absint($whitish_lite_excerpt_length);// this will return 30 words in the excerpt
	}
	add_filter('excerpt_length', 'whitish_lite_excerpt_length');
}

/********************* CONTINUE READING LINKS FOR EXCERPT *********************************/
if (! function_exists('whitish_lite_continue_reading')) {
	function whitish_lite_continue_reading() {
		 return '&hellip; ';
	}
	add_filter('excerpt_more', 'whitish_lite_continue_reading');
}

/***************** USED CLASS FOR BODY TAGS ******************************/
if (! function_exists('whitish_lite_body_class')) {
	function whitish_lite_body_class($classes) {
		$whitish_lite_settings = whitish_lite_get_theme_options();
		$whitish_lite_site_layout = $whitish_lite_settings['whitish_lite_design_layout'];
		$whitish_lite_blog_layout = $whitish_lite_settings['whitish_lite_blog_layout'];

		if (is_page_template('page-templates/page-template-contact.php')) {
				$classes[] = 'contact';
		}
		if ($whitish_lite_site_layout =='boxed-layout') {
			$classes[] = 'boxed-layout';
		}
		if ($whitish_lite_site_layout =='small-boxed-layout') {
			$classes[] = 'boxed-layout-small';
		}
		if ($whitish_lite_blog_layout =='medium_image_display') {
			$classes[] = 'small_image_blog';
		}elseif($whitish_lite_blog_layout =='single_column_blog'){
			$classes[] = 'single_column_blog';
		}
		return $classes;
	}
	add_filter('body_class', 'whitish_lite_body_class');
}

/********************** SCRIPTS FOR DONATE/ UPGRADE BUTTON ******************************/
if (! function_exists('whitish_lite_customize_scripts')) {
	function whitish_lite_customize_scripts() {
		// Load the html5 shiv.
		wp_enqueue_script( 'jquery-html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.3' );
		wp_script_add_data( 'jquery-html5', 'conditional', 'lt IE 9' );
	}
	add_action( 'customize_controls_print_scripts', 'whitish_lite_customize_scripts');
}

/**************************** SOCIAL MENU *********************************************/
if (! function_exists('whitish_lite_add_social_links')) {
	function whitish_lite_add_social_links() { ?>
		<div class="social-links clearfix">
			<?php
			$whitish_lite_settings = whitish_lite_get_theme_options();
			if( !empty($whitish_lite_settings['whitish_lite_social_facebook']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_facebook']).'"><i class="fa fa-facebook"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_twitter']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_twitter']).'"><i class="fa fa-twitter"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_pinterest']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_pinterest']).'"><i class="fa fa-pinterest-p"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_dribbble']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_dribbble']).'"><i class="fa fa-dribbble"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_instagram']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_instagram']).'"><i class="fa fa-instagram"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_flickr']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_flickr']).'"><i class="fa fa-flickr"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_googleplus']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_googleplus']).'"><i class="fa fa-google-plus-official"></i></a>';
			endif;
			if( !empty($whitish_lite_settings['whitish_lite_social_linkedin']) ):
				echo '<a target="_blank" href="'.esc_url($whitish_lite_settings['whitish_lite_social_linkedin']).'"><i class="fa fa-linkedin"></i></a>';
			endif;

			$search_form = $whitish_lite_settings['whitish_lite_search_custom_header'];
				if (1 != $search_form) { ?>
					<div id="search-toggle" class="header-search"></div>
					<div id="search-box" class="clearfix">
						<?php get_search_form();?>
					</div>  <!-- end #search-box -->
					<?php 	}
				?>
		</div><!-- end .social-links -->
	<?php }
	add_action ('whitish_lite_social_links', 'whitish_lite_add_social_links');
}

/******************* DISPLAY BREADCRUMBS ******************************/
if (! function_exists('whitish_lite_breadcrumb')) {
	function whitish_lite_breadcrumb() {
		if (function_exists('bcn_display')) { ?>
			<div class="breadcrumb home">
				<?php bcn_display(); ?>
			</div> <!-- .breadcrumb -->
		<?php }
	}
}

/*********************** Whitish Lite PAGE SLIDERS ***********************************/
if (! function_exists('whitish_lite_page_sliders')) {
	function whitish_lite_page_sliders() {
		$whitish_lite_settings = whitish_lite_get_theme_options();
		$excerpt = get_the_excerpt();
		$slider_custom_text = $whitish_lite_settings['whitish_lite_secondary_text'];
		$slider_custom_url = $whitish_lite_settings['whitish_lite_secondary_url'];
		global $whitish_lite_excerpt_length;
		global $post;
		$whitish_lite_page_sliders_display = '';
		$whitish_lite_total_page_no 		= 0;
		$whitish_lite_list_page				= array();
		for( $i = 1; $i <= $whitish_lite_settings['whitish_lite_slider_no']; $i++ ){
			if( isset ( $whitish_lite_settings['whitish_lite_featured_page_slider_' . $i] ) && $whitish_lite_settings['whitish_lite_featured_page_slider_' . $i] > 0 ){
				$whitish_lite_total_page_no++;
				$whitish_lite_list_page	=	array_merge( $whitish_lite_list_page, array( esc_attr($whitish_lite_settings['whitish_lite_featured_page_slider_' . $i] )) );
			}
		}
			if ( !empty( $whitish_lite_list_page ) && $whitish_lite_total_page_no > 0 ) {
				echo '<div class="main-slider clearfix"> <div class="layer-slider">';
						$get_featured_posts 		= new WP_Query(array( 'posts_per_page'=> $whitish_lite_settings['whitish_lite_slider_no'], 'post_type' => array('page'), 'post__in' => $whitish_lite_list_page, 'orderby' => 'post__in', ));
						$i=0;
				while ($get_featured_posts->have_posts()):$get_featured_posts->the_post();
				$attachment_id = get_post_thumbnail_id();
				$image_attributes = wp_get_attachment_image_src($attachment_id,'whitish_lite_slider_image');
							$i++;
							$title_attribute       	 	 = apply_filters('the_title', get_the_title($post->ID));
							$excerpt               	 	 = substr(get_the_excerpt(), 0 , 160);
							if (1 == $i) {$classes   	 = "slides show-display";} else { $classes = "slides hide-display";}
									?>
					<div class="<?php echo esc_attr($classes); ?>">
						<div class="image-slider clearfix" title="<?php the_title('', '', false); ?>" style="background-image:url(<?php echo esc_url($image_attributes[0]); ?>)">
							<article class="slider-content clearfix">
					<?php

					$remove_link = $whitish_lite_settings['whitish_lite_slider_link'];
						if($remove_link == 0){
							if ($title_attribute != '') {
								echo '<h2 class="slider-title"><a href="'.esc_url(get_permalink()).'" title="'.the_title('', '', false).'" rel="bookmark">'.esc_html(get_the_title()).'</a></h2><!-- .slider-title -->';
							}
						}else{
							echo '<h2 class="slider-title">'.esc_html(get_the_title()).'</h2><!-- .slider-title -->';
						}
						if ($excerpt != '') {
							$excerpt_text = $whitish_lite_settings['whitish_lite_tag_text'];
							echo '<div class="slider-text">';
							echo '<h3>'.esc_html($excerpt).' </h3></div><!-- end .slider-text -->';
						}
						echo '<div class="slider-buttons">';
						if($whitish_lite_settings['whitish_lite_slider_button'] == 0){
							$excerpt_text = $whitish_lite_settings['whitish_lite_tag_text'];
							if($excerpt_text == '' || $excerpt_text == 'Read More') :
								echo '<a title='.'"'.esc_html(get_the_title()). '"'. ' '.'href="'.esc_url(get_permalink()).'"'.' class="btn-default">'.esc_html__('Read More', 'whitish-lite').'</a>';
							else:
							echo '<a title='.'"'.esc_html(get_the_title()). '"'. ' '.'href="'.esc_url(get_permalink()).'"'.' class="btn-default">'.esc_html($whitish_lite_settings[ 'whitish_lite_tag_text' ]).'</a>';
							endif;
								}
							if(!empty($slider_custom_text)){
							echo '<a title="'.esc_attr($slider_custom_text).'"' .' href="'.esc_url($slider_custom_url). '"'. ' class="btn-default" target="_blank">'.esc_attr($slider_custom_text). '</a>';
						}
						echo '</div><!-- end .slider-buttons -->';
						echo '</article><!-- end .slider-content --> ';
					if ($image_attributes) {
						echo '</div><!-- end .image-slider -->';
					}
					echo '</div><!-- end .slides -->';
				endwhile;
				wp_reset_postdata();
				echo '</div>	  <!-- end .layer-slider -->
						<a class="slider-prev" id="prev2" href="#"><i class="fa fa-angle-left"></i></a> <a class="slider-next" id="next2" href="#"><i class="fa fa-angle-right"></i></a>
	  					<nav class="slider-button"> </nav> <!-- end .slider-button -->
					</div> <!-- end .main-slider -->';
			}

	}
}



/*************************** ENQUEING STYLES AND SCRIPTS ****************************************/
if (! function_exists('whitish_lite_scripts')) {
	function whitish_lite_scripts() {
		$whitish_lite_settings = whitish_lite_get_theme_options();
		wp_enqueue_style('bootstrap-css', get_template_directory_uri().'/assets/css/bootstrap.min.css');
		wp_enqueue_style( 'whitish-lite-style', get_stylesheet_uri() );
		wp_enqueue_style('font-awesome', get_template_directory_uri().'/assets/font-awesome/css/font-awesome.min.css');
		wp_enqueue_script('bootstrap-js', get_template_directory_uri().'/assets/js/bootstrap.min.js', array('jquery'), false, true);
		wp_enqueue_script('slick-jquery', get_template_directory_uri().'/assets/js/slick.min.js', array('jquery'), false, true);
		wp_enqueue_script('jquery_cycle_all', get_template_directory_uri().'/assets/js/jquery.cycle.all.min.js', array('jquery'), false, true);
		wp_enqueue_script('whitish-lite-slider', get_template_directory_uri().'/assets/js/whitish-lite-slider-setting.js', array('jquery_cycle_all'), false, true);
		wp_enqueue_script('whitish-lite-main', get_template_directory_uri().'/assets/js/whitish-lite-main.js', array('jquery'), false, true);
		$whitish_lite_stick_menu = $whitish_lite_settings['whitish_lite_stick_menu'];
		if($whitish_lite_stick_menu != 1):
			wp_enqueue_script('jquery-sticky', get_template_directory_uri().'/assets/sticky/jquery.sticky.min.js', array('jquery'), false, true);
		wp_enqueue_script('jquery-sticky-settings', get_template_directory_uri().'/assets/sticky/sticky-settings.js', array('jquery'), false, true);
		endif;

		wp_style_add_data('IE-9', 'conditional', 'lt IE 9');
		wp_enqueue_style('whitish-lite-responsive', get_template_directory_uri().'/assets/css/responsive.css');
		wp_enqueue_style('slick-css', get_template_directory_uri().'/assets/css/slick.css');

		/********* Adding Multiple Fonts ********************/
		$whitish_lite_googlefont = array();
		array_push( $whitish_lite_googlefont, 'Open+Sans');
		array_push( $whitish_lite_googlefont, 'Playfair+Display');
		$whitish_lite_googlefonts = implode("|", $whitish_lite_googlefont);
		wp_register_style( 'whitish_lite_google_fonts', '//fonts.googleapis.com/css?family='.$whitish_lite_googlefonts);
		wp_enqueue_style( 'whitish_lite_google_fonts' );
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'whitish_lite_scripts' );
}

if (! function_exists('whitish_lite_blog_post_format')) {
	function whitish_lite_blog_post_format($post_format, $post_id) {
		global $post;
		$whitish_lite_settings = whitish_lite_get_theme_options();
		$blog_layout = $whitish_lite_settings['whitish_lite_blog_layout'];
		$blog_image_size  = ($blog_layout == 'large_image_display')?'whitish-lite-grid-image':'full';
		$blog_image_id    = get_post_thumbnail_id();
	    $blog_image_url   = wp_get_attachment_image_src( $blog_image_id, $blog_image_size );
	    $blog_image_title = get_the_title($blog_image_id);

		if (is_single()){
			$single_post_format_class = 'single-post-format';
		} else {
			$single_post_format_class = '';
		}

		$whitish_lite_settings = whitish_lite_get_theme_options();

		if($post_format == 'video'){ ?>
			<div class="post-video <?php echo esc_attr($single_post_format_class);?>">
				<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog') { if (!is_single()) { whitish_lite_entry_header(); }} ?>
				<div class="post-video-holder">
					<?php
						$content = trim(get_post_field('post_content', $post->ID));
	                    $ori_url = explode("\n", esc_html($content));
	                    $url =  $ori_url[0] ;
	                    $url_type = explode(" ", $url);
	                    $url_type = explode("[", $url_type[0]);

	                    if (isset($url_type[1])){
	                        $url_type_shortcode = $url_type[1];
	                    }
	                    $new_content =  get_shortcode_regex();
	                    if (isset($url_type[1])){
	                       if ( preg_match_all( '/'. $new_content .'/s', $post->post_content, $matches )
	                            && array_key_exists( 2, $matches )
	                            && in_array( $url_type_shortcode, $matches[2] )  )
	                        {
	                             echo do_shortcode($matches[0][0]);
	                        }
	                    }
	                     else {
	                        echo esc_html(whitish_lite_the_featured_video($content));
	                     }
			        ?>
				</div>
			</div>
		<?php
		}
		elseif($post_format == 'audio'){
			?>
				<div class="post-audio <?php echo esc_attr($single_post_format_class);?>">
					<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog') { if (!is_single()) { whitish_lite_entry_header(); }} ?>
					<div class="post-audio-holder">
						<?php
							$content = trim(  get_post_field('post_content', $post_id) );
				              $ori_url = explode( "\n", esc_html( $content ) );
				            $new_content =  preg_match_all("/\[[^\]]*\]/", $content, $matches);
				            if( $new_content){
				                echo do_shortcode( $matches[0][0] );
				            }
				            elseif (preg_match ( '#^<(script|iframe|embed|object)#i', $content )) {
				                $regex = '/https?\:\/\/[^\" ]+/i';
				                preg_match_all($regex, $ori_url[0], $matches);
				                $urls = ($matches[0]);
				                 print_r('<iframe src="'.esc_url($urls[0]).'" width="100%" height="240" frameborder="no" scrolling="no"></iframe>');
				            } elseif (0 === strpos( $content, 'https://' )) {
				                $embed_url = wp_oembed_get( esc_url( $ori_url[0] ) );
				                print_r($embed_url);
				            }
						?>
					</div>
				</div>
			<?php
		}
		elseif ($post_format == 'gallery') {

			if (!is_single()) {
				//Get the alt and title of the image
			    $image_url = get_post_gallery_images( $post );

			    if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'tiled-gallery' ) ) {
			    	$gallery = get_post_gallery();
			    	if ($gallery) {
			    		echo '<div class="whitish-lite-jetpack-gallery">';
		                	echo wp_kses_post($gallery);
				    		 if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog') { if (!is_single()) { whitish_lite_entry_header(); }}
		                echo '</div>';
	                } else {
	                	 ?>
								<div class="post-image-content">
									<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog') { if (!is_single()) { whitish_lite_entry_header(); }} ?>
									<figure class="post-featured-image">
										<a href="<?php the_permalink();?>" title="<?php echo the_title_attribute('echo=0'); ?>">
										<img src="<?php echo esc_url($blog_image_url[0]);?>">
										</a>
									</figure><!-- end.post-featured-image  -->
								</div> <!-- end.post-image-content -->
				<?php
	                }
				}

				else {

				    if( $image_url ) {
						?>
						<div class="post-gallery-wrap">
							<div class="post-gallery">
								<?php foreach ( $image_url as $key => $images ) {
				    					$image_id = attachment_url_to_postid($images);
				    					$alt_tag = get_post_meta($image_id, '_wp_attachment_image_alt', true);
									?>
									<div class="post-gallery-item">
										<div class="post-gallery-item-holder" style="background-image: url('<?php echo esc_url( $images); ?>');" <?php if($alt_tag) { ?>alt= "<?php echo esc_attr($alt_tag);?>"<?php } ?>>
										</div>
									</div>
								<?php } ?>
							</div>
					<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog' && !is_single()) { whitish_lite_entry_header(); } ?>
						</div>
						<?php

					}

						else {
							 ?>
								<div class="post-image-content">
									<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog' && !is_single()) { whitish_lite_entry_header(); } ?>
									<figure class="post-featured-image">
										<a href="<?php the_permalink();?>" title="<?php echo the_title_attribute('echo=0'); ?>">
										<img src="<?php echo esc_url($blog_image_url[0]);?>">
										</a>
									</figure><!-- end.post-featured-image  -->
								</div> <!-- end.post-image-content -->
				<?php
					}


				}
			} else {

				 ?>
						<div class="post-image-content">
							<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog' && !is_single()) { whitish_lite_entry_header(); } ?>
							<figure class="post-featured-image">
								<a href="<?php the_permalink();?>" title="<?php echo the_title_attribute('echo=0'); ?>">
								<img src="<?php echo esc_url($blog_image_url[0]);?>">
								</a>
							</figure><!-- end.post-featured-image  -->
						</div> <!-- end.post-image-content -->
		<?php

			}
		 }
				else {
					 ?>
						<div class="post-image-content">
							<?php if ($blog_layout == 'large_image_display' || $blog_layout == 'single_column_blog') { if (!is_single()) { whitish_lite_entry_header(); }} ?>
							<figure class="post-featured-image">
								<a href="<?php the_permalink();?>" title="<?php echo the_title_attribute('echo=0'); ?>">
								<img src="<?php echo esc_url($blog_image_url[0]);?>">
								</a>
							</figure><!-- end.post-featured-image  -->
						</div> <!-- end.post-image-content -->
		<?php
	}
}
}

function whitish_lite_entry_header() {
	$whitish_lite_settings = whitish_lite_get_theme_options();
	?>
	<header class="entry-header">
		<?php $entry_format_meta_blog = $whitish_lite_settings['whitish_lite_entry_meta_blog'];
		 if($entry_format_meta_blog == 'show-meta'){ ?>
			<div class="entry-meta">
				<span class="cat-links">
					<?php the_category(', '); ?>
				</span> <!-- end .cat-links -->
			</div><!-- end .entry-meta -->
		<?php } ?>

			<h2 class="entry-title"> <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute();?>"> <?php the_title();?> </a> </h2> <!-- end.entry-title -->
	</header><!-- end .entry-header -->
	<?php
}

if (! function_exists('whitish_lite_author_description')) {
	function whitish_lite_author_description($author_id) {
		$author_name = get_the_author_meta( 'display_name' );
        $author_firstname = get_the_author_meta( 'first_name' );
        $author_lastname = get_the_author_meta( 'last_name' );
        $author_id = get_the_author_meta( 'ID' );
        $author_description = get_the_author_meta('description', $author_id);
        $author_image = get_avatar($author_id);
		?>
		 <div class="author-bio">
            <div class="row">
                <div class="col-md-2">
                    <div class="author-image">
                        <?php echo wp_kses_post($author_image); ?>
                    </div>
                </div>
                <div class="col-md-9">
                    <div class="author-desc">
                        <span class="author-name"><a href="<?php echo esc_url(get_author_posts_url( $author_id));?>"><?php if ( $author_firstname && $author_lastname ) { ?><?php echo esc_html($author_firstname). ' ' . esc_html( $author_lastname); ?><?php } else { echo esc_html($author_name);}?></a></span>
                        <?php if ($author_description) { ?>
                            <p><?php echo esc_html($author_description); ?></p>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
		<?php
	}
}

if (! function_exists('whitish_lite_sanitize_css')) {
	function whitish_lite_sanitize_css( $input ) {
	    return wp_filter_nohtml_kses( $input );
	}
}

if (! function_exists('whitish_lite_sanitize_url')) {
	function whitish_lite_sanitize_url( $url ) {
		return esc_url_raw($url);
	}
}
